@@ -13,16 +13,16 @@ class Article(object):
     content = Column(Text)
 
 if __name__ == '__main__':
-    database = Database('sqlite://')
-    database.create_tables()
+    db = Database('sqlite://')
+    db.create_tables()
     
     author = User(name = 'Tyler Long')
     editor = User(name = 'Peter Lau')
     article = Article(author = author, editor = editor, title = 'Quick ORM is super quick and easy', 
         content = 'Quick ORM is super quick and easy. Believe it or not.')
-    database.session.add_then_commit(article)
+    db.session.add_then_commit(article)
     
-    article = database.session.query(Article).get(1)
+    article = db.session.query(Article).get(1)
     print 'Article:', article.title
     print 'Author:', article.author.name
     print 'Editor:', article.editor.name
